summaryrefslogtreecommitdiff
path: root/etc
diff options
context:
space:
mode:
authorMarius Bakke <mbakke@fastmail.com>2020-04-15 19:26:55 +0200
committerMarius Bakke <mbakke@fastmail.com>2020-04-15 19:26:55 +0200
commitbd21acf6c390e4fe87eb6053f0b5185d6ecbcf9f (patch)
tree09fe91a8351471e5e7a821cb28521dd9b9d7e357 /etc
parenta4f1a7e2db22cd028fb514846c2791928b8734d3 (diff)
parentb44e19acd1a0d449427cea0333f02ac98605be1c (diff)
downloadpatches-bd21acf6c390e4fe87eb6053f0b5185d6ecbcf9f.tar
patches-bd21acf6c390e4fe87eb6053f0b5185d6ecbcf9f.tar.gz
Merge branch 'master' into core-updates
Diffstat (limited to 'etc')
-rw-r--r--etc/release-manifest.scm30
1 files changed, 20 insertions, 10 deletions
diff --git a/etc/release-manifest.scm b/etc/release-manifest.scm
index 0c864041bc..caa200c673 100644
--- a/etc/release-manifest.scm
+++ b/etc/release-manifest.scm
@@ -23,6 +23,7 @@
(guix packages)
(guix profiles)
((gnu ci) #:select (%cross-targets))
+ ((gnu services xorg) #:select (%default-xorg-modules))
(guix utils)
(srfi srfi-1)
(srfi srfi-26))
@@ -49,16 +50,17 @@ TARGET."
(define %system-packages
;; Key packages proposed by the Guix System installer.
- (map specification->package
- '("xorg-server" "xfce" "gnome" "mate" "enlightenment"
- "openbox" "awesome" "i3-wm" "ratpoison"
- "xlockmore" "slock" "libreoffice"
- "connman" "network-manager" "network-manager-applet"
- "openssh" "ntp" "tor"
- "linux-libre" "grub-hybrid"
- ;; FIXME: Add IceCat when Rust is available on i686.
- ;;"icecat"
- )))
+ (append (map specification->package
+ '("xorg-server" "xfce" "gnome" "mate" "enlightenment"
+ "openbox" "awesome" "i3-wm" "ratpoison"
+ "xlockmore" "slock" "libreoffice"
+ "connman" "network-manager" "network-manager-applet"
+ "openssh" "ntp" "tor"
+ "linux-libre" "grub-hybrid"
+ ;; FIXME: Add IceCat when Rust is available on i686.
+ ;;"icecat"
+ ))
+ %default-xorg-modules))
(define %packages-to-cross-build
;; Packages that must be cross-buildable from x86_64-linux.
@@ -93,6 +95,13 @@ TARGET."
%base-packages))
%hydra-supported-systems)))
+(define %system-manifest
+ (manifest
+ (append-map (lambda (system)
+ (map (cut package->manifest-entry* <> system)
+ %system-packages))
+ '("x86_64-linux" "i686-linux")))) ;Guix System
+
(define %cross-manifest
(manifest
(append-map (lambda (target)
@@ -115,5 +124,6 @@ TARGET."
;; Return the union of all three manifests.
(concatenate-manifests (list %base-manifest
+ %system-manifest
%cross-manifest
%cross-bootstrap-manifest))